@@ -10,7 +10,7 @@ def program(year):
     Parameters
     ----------
     year: int
-        année (présentement entre 2020 et 2021)
+        année (présentement entre 2020 et 2022)
     Returns
     -------
     class instance
@@ -20,6 +20,8 @@ def program(year):
         p = program_2020()
     if year == 2021:
         p = program_2021()
+    if year == 2022:
+        p = program_2022()
     return p
 class program_2020(template):
     """
@@ -110,3 +112,30 @@ class program_2021(program_2020):
             Montant de PIRTE pour les 16 semaines.
         """
         return 0
+
+class program_2022(program_2021):
+    """
+    Version du programme de 2022.
+
+    Calcule principalement la Prestation canadienne de la relance économique (PCRE)
+    """
+
+    def __init__(self):
+        add_params_as_attr(self, module_dir + "/covid/params/measures_2022.csv")
+
+    def compute_crb(self, p):
+        """
+        Fonction qui calcule la Prestation canadienne de la relance économique (PCRE). La PCRE était disponible entre le 27 septembre 2020 et le 23 octobre 2021.
+
+        Calcule la PCRE pour la période de 54 semaines si le travailleur est admissible.
+
+        Parameters
+        ----------
+        p: Person
+            instance de la classe Person
+        Returns
+        -------
+        float
+            Montant de la PCRE.
+        """
+        return 0
\ No newline at end of file
