@@ -17,10 +17,9 @@ class template:
 
     def file(self, hh):
         """
-        Fonction qui permet de calculer les impôts.
+        Fonction qui permet de calculer l'impôt.
 
-        Cette fonction est celle qui calcule les déductions,
-        les crédits non-remboursables et remboursables et les impôts nets.
+        Cette fonction est celle qui calcule les déductions,les crédits non-remboursables et remboursables et l'impôt net.
 
         Parameters
         ----------
@@ -38,9 +37,9 @@ class template:
             self.calc_tax(p)
             self.calc_non_refundable_tax_credits(p, hh)
             self.div_tax_credit(p)
-            p.fed_return['net_tax_liability'] = max(0,
-                p.fed_return['gross_tax_liability'] - p.fed_return['non_refund_credits']
-                - p.fed_div_tax_credit)
+        for p in hh.sp:
+            p.fed_return['net_tax_liability'] = max(0, p.fed_return['gross_tax_liability'] - p.fed_return['non_refund_credits']
+                 - self.get_spouse_transfer(p, hh) - p.fed_div_tax_credit)
             self.calc_refundable_tax_credits(p, hh)
             p.fed_return['net_tax_liability'] -= p.fed_return['refund_credits']
 
@@ -59,7 +58,9 @@ class template:
                          + self.div_other_can_factor * p.div_other_can)
         p.taxable_cap_gains = self.cap_gains_rate * max(0, p.net_cap_gains)
         p.fed_return['gross_income'] = (p.inc_work + p.inc_ei + p.inc_oas
-                                        + p.inc_gis + p.inc_cpp + p.inc_rpp
+                                        + p.inc_gis + p.allow_couple
+                                        + p.allow_surv
+                                        + p.inc_cpp + p.inc_rpp
                                         + p.pension_split + p.taxable_div
                                         + p.taxable_cap_gains
                                         + p.inc_othtax + p.inc_rrsp)
@@ -105,7 +106,7 @@ class template:
         p.fed_cpp_deduction = self.cpp_deduction(p)
         p.fed_qpip_deduction = self.qpip_deduction(p)
         p.fed_return['deductions_gross_inc'] = (p.con_rrsp + p.con_rpp
-                                                + p.inc_gis + p.fed_chcare
+                                                + p.fed_chcare
                                                 + p.pension_deduction
                                                 + p.union_dues
                                                 + p.fed_cpp_deduction
@@ -126,9 +127,7 @@ class template:
         float
             Montant de la déduction pour frais de garde.
 
-            Cette fonction calcule le montant reçu en fonction des frais de garde,
-            de l'âge des enfants et du revenu le moins élevé du couple. Le montant
-            est reçu par le conjoint qui a le revenu le moins élevé.
+            Cette fonction calcule le montant reçu en fonction des frais de garde, de l'âge des enfants et du revenu le moins élevé du couple. Le montant est reçu par le conjoint qui a le revenu le moins élevé.
         """
 
         if hh.child_care_exp == 0:
@@ -143,7 +142,7 @@ class template:
 
     def cpp_deduction(self, p):
         """
-        Fonction qui calcule la déduction pour les cotisations au RRQ / RPC pour les travailleurs autonomes.
+        Fonction qui calcule la déduction pour les cotisations au RRQ/RPC pour les travailleurs autonomes.
 
         Parameters
         ----------
@@ -156,7 +155,8 @@ class template:
             Montant de la déduction.
         """
         try:
-            return p.contrib_cpp_self / 2
+            p.contrib_cpp_deduc = p.contrib_cpp_self / 2
+            return p.contrib_cpp_deduc
         except AttributeError as e:
             msg = 'le ménage doit être passé dans payroll pour obtenir les contributions cpp/rrq et rqap'
             raise Exception(msg) from e
@@ -180,7 +180,7 @@ class template:
     def calc_deduc_net_income(self, p):
         """
         Fonction qui calcule les déductions suivantes:
-        1. Pertes en capital net des autres années;
+        1. Pertes en capital nettes d'autres années;
         2. Déduction pour gain en capital exonéré.
 
         Permet une déduction maximale égale aux gains en capital taxables nets.
@@ -190,8 +190,10 @@ class template:
         p: Person
             instance de la classe Person
         """
-        p.fed_return['deductions_net_inc'] = min(p.taxable_cap_gains,
-            p.prev_cap_losses + self.cap_gains_rate * p.cap_gains_exempt)
+        p.fed_return['deductions_net_inc'] = min(
+            p.taxable_cap_gains,
+            p.inc_gis + p.allow_couple + p.allow_surv
+            + p.prev_cap_losses + self.cap_gains_rate * p.cap_gains_exempt)
 
     def calc_tax(self, p):
         """
@@ -224,6 +226,7 @@ class template:
         """
         p.fed_age_cred = self.get_age_cred(p)
         p.fed_cpp_contrib_cred = self.get_cpp_contrib_cred(p)
+        p.fed_ei_contrib_cred = self.get_ei_contrib_cred(p)
         p.fed_qpip_cred = self.get_qpip_cred(p)
         p.fed_qpip_self_cred = self.get_qpip_self_cred(p)
         p.fed_empl_cred = self.get_empl_cred(p)
@@ -231,11 +234,14 @@ class template:
         p.fed_disabled_cred = self.get_disabled_cred(p)
         p.fed_med_exp_nr_cred = self.get_med_exp_nr_cred(p, hh)
         p.donation_cred = self.get_donations_cred(p)
+        p.fed_dep_cred = self.get_dep_cred(p, hh)
+        p.fed_spouse_cred = self.get_spouses_cred(p, hh)
+
 
         p.fed_return['non_refund_credits'] = (self.rate_non_ref_tax_cred
-            * (self.compute_basic_amount(p) + p.fed_age_cred
-               + p.fed_cpp_contrib_cred + p.fed_qpip_cred +
-               + p.fed_qpip_self_cred + p.fed_empl_cred + p.fed_pension_cred
+            * (self.compute_basic_amount(p)+ p.fed_dep_cred + p.fed_spouse_cred + p.fed_age_cred
+               + p.fed_cpp_contrib_cred + p.fed_ei_contrib_cred + p.fed_qpip_cred +
+               + p.fed_qpip_self_cred + p.fed_empl_cred  + p.fed_pension_cred
                + p.fed_disabled_cred + p.fed_med_exp_nr_cred)
                + p.donation_cred)
 
@@ -277,9 +283,25 @@ class template:
         clawback = self.age_cred_claw_rate * max(0, p.fed_return['net_income'] - self.age_cred_exempt)
         return max(0, self.age_cred_amount - clawback)
 
+    def get_ei_contrib_cred(self, p):
+        """
+        Fonction qui calcule le crédit d'impôt non-remboursable pour cotisations à l'assurance emploi.
+
+        Parameters
+        ----------
+        p: Person
+            instance de la classe Person
+
+        Returns
+        -------
+        float
+            Montant du crédit.
+        """
+        return p.contrib_ei
+
     def get_cpp_contrib_cred(self, p):
         """
-        Fonction qui calcule le crédit d'impôt non-remboursable pour cotisations au RRQ / RPC.
+        Fonction qui calcule le crédit d'impôt non-remboursable pour cotisations au RRQ/RPC.
 
         Parameters
         ----------
@@ -446,6 +468,36 @@ class template:
                     + donation_high_inc * self.donation_high_rate
                     + donation_low_inc * self.donation_med_rate)
 
+    def get_spouse_transfer(self, p, hh):
+        """
+        Fonction qui récupère le surplus des crédits non-remboursables transférables au conjoint (s'il y lieu).
+
+        Parameters
+        ----------
+        p: Person
+            instance de la classe Person
+        hh: Hhold
+            instance de la classe Hhold
+        """
+        if not hh.couple:
+            return 0
+
+        spouse = hh.sp[1 - hh.sp.index(p)]
+        first_cred = spouse.fed_age_cred + spouse.fed_pension_cred
+        if spouse.fed_return['taxable_income'] <= self.l_brackets[1]:
+            taxable_inc = spouse.fed_return['taxable_income']
+        else:
+            taxable_inc = spouse.fed_return['gross_tax_liability']/ self.l_rates[0]
+
+        income_deduction = self.compute_basic_amount(spouse) + spouse.contrib_cpp + spouse.contrib_cpp_self + spouse.contrib_qpip \
+        + spouse.contrib_qpip_self + spouse.contrib_ei + spouse.fed_empl_cred
+
+        net_inc = max(0, taxable_inc - income_deduction)
+        transfer = max(0, first_cred - net_inc)
+
+        return self.l_rates[0] * transfer
+
+
     def div_tax_credit(self, p):
         """
         Fonction qui calcule le crédit d'impôt pour dividendes.
@@ -461,7 +513,7 @@ class template:
 
     def calc_refundable_tax_credits(self, p, hh):
         """
-        Fonction qui fait la somme des crédits remboursables, en appelant les fonctions suivantes, décrites ci-après: *abatment*, *ccb*, *get_witb*, *get_witbds*, *med_exp*, *gst_hst_credit*.
+        Fonction qui fait la somme des crédits remboursables, en appelant les fonctions suivantes, décrites ailleurs dans cette page: *abatment*, *ccb*, *get_witb*, *get_witbds*, *med_exp*, *gst_hst_credit*.
 
         Parameters
         ----------
@@ -552,7 +604,7 @@ class template:
     def get_witb(self, p, hh):
         """
         Fonction qui calcule l'Allocation canadienne pour les travailleurs (ACT).
-        
+
         Avant 2019, celle-ci était appelée la Prestation fiscale pour le revenu de travail (PFRT).
 
         Dans le cas d'un couple, la prestation est répartie au prorata des revenus de travail.
@@ -566,7 +618,7 @@ class template:
         Returns
         -------
         float
-            Montant de la PFRT.
+            Montant de l'ACT.
         """
         self.witb = self.witb_params['qc'] if hh.prov == 'qc' else self.witb_params['on']
 
@@ -605,7 +657,7 @@ class template:
         Returns
         -------
         float
-            Montant du SIPFRT.
+            Montant du supplépment pour invalidité.
         """
         if not p.disabled:
             return 0
@@ -628,8 +680,8 @@ class template:
     def compute_witb_witbds(self, p, hh, rate, base, witb_max, claw_rate,
                             exemption):
         """
-        Fonction appelée par *get_witb* et *get_witbds* pour calculer 
-        le montant de la PFRT et du SIPFRT.
+        Fonction appelée par *get_witb* et *get_witbds* pour calculer
+        le montant de la PFRT / l'ACT et de son supplément.
 
         Parameters
         ----------
@@ -640,9 +692,9 @@ class template:
         rate: float
             taux appliqué au revenu du travail
         base: float
-            montant de base de la PFRT
+            montant de base de la PFRT / l'ACT
         witb_max: float
-            montant maximal de la PFRT
+            montant maximal de la PFRT / l'ACT
         claw_rate:
             taux de réduction
         exemption: float
@@ -651,7 +703,7 @@ class template:
         Returns
         -------
         float
-            Montant de la PFRT ou du SIPFRT.
+            Montant de la PFRT / l'ACT ou du supplément.
         """
         amount = rate * max(0, hh.fam_inc_work - base)
         adj_amount = min(witb_max, amount)
@@ -713,3 +765,85 @@ class template:
                           self.gst_cred_rate * max(0, hh.fam_net_inc_fed - self.gst_cred_base_amount))
 
         return max(0, amount - clawback)
+
+    def get_dep_cred(self, p , hh):
+        """
+        Fonction qui calcule le montant pour personne à charge admissible.
+
+        Ce crédit est non-remboursable.
+
+        Parameters
+        ----------
+        p: Person
+            instance de la classe Person
+        hh: Hhold
+            instance de la classe Hhold
+
+        Returns
+        -------
+        float
+            Montant du crédit.
+        """
+        if hh.couple:
+            return 0
+
+        amount = amount_dis = nchild_dis = nchild = 0
+        nchild += len(hh.dep)
+        if nchild == 0:
+            return 0
+        else:
+            amount += self.compute_basic_amount(p)
+            for d in hh.dep:
+                if d.disa:
+                    nchild_dis +=1
+            if nchild_dis >= 1:
+                amount_dis += self.dep_disa_amount
+            return amount + amount_dis
+
+    def get_spouses_cred(self, p, hh):
+        """
+        Fonction qui calcule le montant pour époux ou conjoint de fait.
+
+        Ce crédit est non-remboursable.
+
+        Parameters
+        ----------
+        p: Person
+            instance de la classe Person
+        hh: Hhold
+            instance de la classe Hhold
+
+        Returns
+        -------
+        float
+            Montant du crédit.
+        """
+        if hh.couple:
+            higher_inc, equal_inc = 0,0
+            if hh.sp[0].fed_return['net_income'] > hh.sp[1].fed_return['net_income']:
+                higher_inc = hh.sp[0].fed_return['net_income']
+            elif hh.sp[1].fed_return['net_income'] > hh.sp[0].fed_return['net_income']:
+                higher_inc = hh.sp[1].fed_return['net_income']
+            else:
+                equal_inc = hh.sp[1].fed_return['net_income']
+        elif not hh.couple or (p.fed_dep_cred != 0):
+            return 0
+
+        amount = 0
+        if p.fed_return['net_income'] == higher_inc :
+            amount += self.compute_basic_amount(p)
+            spouse = hh.sp[1 - hh.sp.index(p)]
+            if spouse.disabled:
+                amount += self.nrtc_spouse_dis
+            amount-= spouse.fed_return['net_income']
+            return max(0, amount)
+        elif p.fed_return['net_income'] == equal_inc:
+            amount += self.compute_basic_amount(p)
+            spouse = hh.sp[1 - hh.sp.index(p)]
+            if spouse.disabled:
+                amount += self.nrtc_spouse_dis
+            amount-= spouse.fed_return['net_income']
+            spouse.fed_spouse_cred = 0
+            return max(0, amount)
+        else:
+            return max(0, amount)
